@@ -30,7 +30,7 @@
 #include "clutter-backend.h"
 #include "clutter-debug.h"
 #include "clutter-device-manager-private.h"
-#include "clutter-event.h"
+#include "clutter-event-private.h"
 #include "clutter-keysyms.h"
 #include "clutter-main.h"
 #include "clutter-private.h"
