@@ -34,6 +34,7 @@
 #include "clutter-backend.h"
 #include "clutter-debug.h"
 #include "clutter-device-manager-private.h"
+#include "clutter-event-private.h"
 #include "clutter-event-translator.h"
 #include "clutter-stage-private.h"
 #include "clutter-private.h"
@@ -80,7 +81,7 @@ translate_valuator_class (Display             *xdisplay,
                           XIValuatorClassInfo *class)
 {
   static gboolean atoms_initialized = FALSE;
-  ClutterInputAxis axis, i;
+  ClutterInputAxis i, axis = CLUTTER_INPUT_AXIS_IGNORE;
 
   if (G_UNLIKELY (!atoms_initialized))
     {
@@ -326,7 +327,6 @@ translate_hierarchy_event (ClutterBackendX11       *backend_x11,
                            ClutterDeviceManagerXI2 *manager_xi2,
                            XIHierarchyEvent        *ev)
 {
-  ClutterInputDevice *device;
   int i;
 
   for (i = 0; i < ev->num_info; i++)
@@ -341,7 +341,7 @@ translate_hierarchy_event (ClutterBackendX11       *backend_x11,
           info = XIQueryDevice (backend_x11->xdpy,
                                 ev->info[i].deviceid,
                                 &n_devices);
-          device = add_device (manager_xi2, backend_x11, &info[0], FALSE);
+          add_device (manager_xi2, backend_x11, &info[0], FALSE);
         }
       else if (ev->info[i].flags & XIDeviceDisabled)
         {
@@ -1043,9 +1043,8 @@ clutter_device_manager_xi2_constructed (GObject *gobject)
   for (i = 0; i < n_devices; i++)
     {
       XIDeviceInfo *xi_device = &info[i];
-      ClutterInputDevice *device;
 
-      device = add_device (manager_xi2, backend_x11, xi_device, TRUE);
+      add_device (manager_xi2, backend_x11, xi_device, TRUE);
 
       if (xi_device->use == XIMasterPointer ||
           xi_device->use == XIMasterKeyboard)
