@@ -42,7 +42,6 @@ move_actors (ClutterActor *actor,
              gpointer      user_data)
 {
   State *state = (State *) user_data;
-  GList *keys;
 
   /* do nothing if the animator is already running */
   if (clutter_timeline_is_playing (clutter_animator_get_timeline (state->animator)))
@@ -74,7 +73,8 @@ main (int   argc,
   /* seed random number generator */
   srand ((unsigned int) time (NULL));
 
-clutter_init (&argc, &argv);
+if (clutter_init (&argc, &argv) != CLUTTER_INIT_SUCCESS)
+    return 1;
 
   state->animator = clutter_animator_new ();
   clutter_animator_set_duration (state->animator, 500);
